==> hbase-client-1.1.2-sources.jar: org/apache/hadoop/hbase/util/JsonMapper.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.util;

import java.io.IOException;
import java.util.Map;

import org.apache.hadoop.hbase.classification.InterfaceAudience;
import org.apache.hadoop.hbase.classification.InterfaceStability;
import org.codehaus.jackson.map.ObjectMapper;

/**
 * Utility class for converting objects to JSON
 */
@InterfaceAudience.Public
@InterfaceStability.Evolving
public final class JsonMapper {
  private JsonMapper() {
  }

  private static final ObjectMapper MAPPER = new ObjectMapper();

  public static String writeMapAsString(Map<String, Object> map) throws IOException { 
    return writeObjectAsString(map);
  }
  public static String writeObjectAsString(Object object) throws IOException { 
    return MAPPER.writeValueAsString(object);
  }
}

==> hbase-client-1.5.0-sources.jar: org/apache/hadoop/hbase/util/JsonMapper.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.util;

import java.io.IOException;
import java.util.Map;

import org.apache.hadoop.hbase.classification.InterfaceAudience;
import org.apache.hadoop.hbase.classification.InterfaceStability;
import org.apache.hbase.thirdparty.com.google.gson.Gson;

/**
 * Utility class for converting objects to JSON
 */
@InterfaceAudience.Public
@InterfaceStability.Evolving
public final class JsonMapper {
  private JsonMapper() {
  }

  private static final Gson GSON = GsonUtil.createGson().create();

  public static String writeMapAsString(Map<String, Object> map) throws IOException {
    return writeObjectAsString(map);
  }

  public static String writeObjectAsString(Object object) throws IOException {
    return GSON.toJson(object);
  }
}
